@@ -3,6 +3,8 @@ Constants for ocrd_utils.
 """
 from pkg_resources import get_distribution
 from re import compile as regex_compile
+from os import environ
+from os.path import join, expanduser
 
 __all__ = [
     'EXT_TO_MIME',
@@ -14,7 +16,10 @@ __all__ = [
     'PIL_TO_MIME',
     'REGEX_PREFIX',
     'REGEX_FILE_ID',
+    'RESOURCE_LOCATIONS',
     'VERSION',
+    'XDG_CONFIG_HOME',
+    'XDG_DATA_HOME',
 ]
 
 VERSION = get_distribution('ocrd_utils').version
@@ -91,3 +96,13 @@ REGEX_FILE_ID = regex_compile(r'^[a-zA-Z_][\w.-]*$')
 # Log level format implementing https://ocr-d.de/en/spec/cli#logging
 LOG_FORMAT = r'%(asctime)s.%(msecs)03d %(levelname)s %(name)s - %(message)s'
 LOG_TIMEFMT = r'%H:%M:%S'
+
+# See https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
+if 'HOME' in environ and environ['HOME'] != expanduser('~'):
+    HOME = environ['HOME']
+else:
+    HOME = expanduser('~')
+XDG_DATA_HOME = environ['XDG_DATA_HOME'] if 'XDG_DATA_HOME' in environ else join(HOME, '.local', 'share')
+XDG_CONFIG_HOME = environ['XDG_CONFIG_HOME'] if 'XDG_CONFIG_HOME' in environ else join(HOME, '.config')
+
+RESOURCE_LOCATIONS = ['data', 'cwd', 'system']
